DidWebVhDocumentMetadata class

Metadata for a DID WebVH document.

This class extends DidDocumentMetadata and represents metadata specific to DID documents that use the WebVH (Web Verifiable Hash) method.

Constructors

DidWebVhDocumentMetadata({String? scid, String? versionId, DateTime? versionTime, int? versionNumber})
Creates a new instance of DidWebVhDocumentMetadata.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scid String?
The Self-Certifying Identifier (SCID) for this DID.
getter/setter pair
versionId String?
The version identifier of the resolved DID Document.
getter/setter pair
versionNumber int?
The sequential version number of the resolved DID Document.
getter/setter pair
versionTime DateTime?
The timestamp when this version of the DID Document was created.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited