SignatureScheme enum

Supported signature schemes. Set of supported signature schemes, all schemes must be fully specified including hashing algorithm, curve and key material requirements.

Inheritance
Available extensions

Values

ecdsa_secp256k1_sha256 → const SignatureScheme

ECDSA with secp256k1 curve and SHA-256 hashing.

const SignatureScheme(alg: 'ES256K', crv: 'secp256k1', keyType: KeyType.secp256k1, hashingAlgorithm: HashingAlgorithm.sha256)
ecdsa_p256_sha256 → const SignatureScheme

ECDSA with P-256 curve and SHA-256 hashing.

const SignatureScheme(alg: 'ES256', crv: 'P-256', keyType: KeyType.p256, hashingAlgorithm: HashingAlgorithm.sha256)
ecdsa_p384_sha384 → const SignatureScheme

ECDSA with P-384 curve and SHA-384 hashing.

const SignatureScheme(alg: 'ES384', crv: 'P-384', keyType: KeyType.p384, hashingAlgorithm: HashingAlgorithm.sha384)
ecdsa_p521_sha512 → const SignatureScheme

ECDSA with P-521 curve and SHA-512 hashing.

const SignatureScheme(alg: 'ES512', crv: 'P-521', keyType: KeyType.p521, hashingAlgorithm: HashingAlgorithm.sha512)
ed25519 → const SignatureScheme

EdDSA with Ed25519 curve and SHA-512 hashing.

const SignatureScheme(alg: 'Ed25519', crv: 'Ed25519', keyType: KeyType.ed25519, hashingAlgorithm: HashingAlgorithm.sha512)
rsa_pkcs1_sha256 → const SignatureScheme

RSA with PKCS1 and SHA-256 hashing.

const SignatureScheme(alg: 'RS256', crv: null, keyType: KeyType.rsa, hashingAlgorithm: HashingAlgorithm.sha256)

Properties

alg String?
The algorithm identifier.
final
crv String?
The curve identifier.
final
hashCode int
The hash code for this object.
no setterinherited
hashingAlgorithm HashingAlgorithm
The hashing algorithm.
final
index int
A numeric identifier for the enumerated value.
no setterinherited
keyType KeyType
The key type.
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SignatureScheme>
A constant List of the values in this enum, in order of their declaration.