VerificationMethodJwk class

Represents a verification method using JWK.

Inheritance

Constructors

VerificationMethodJwk({required String id, required String controller, required String type, required Jwk publicKeyJwk})
Creates a VerificationMethodJwk instance.

Properties

controller String
The controller of the embedded verification method.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
The identifier of the embedded verification method.
finalinherited
isReference bool
Whether this embedded verification method is a reference.
no setterinherited
publicKeyJwk Jwk
The public key in JWK format.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of the embedded verification method.
finalinherited

Methods

asJwk() Jwk
Returns the JWK representation of the verification method.
override
asMultiKey() Uint8List
Returns the multikey representation of the verification method.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this embedded verification method to a JSON-serializable map.
override
toString() String
Returns the JSON string representation of the embedded verification method.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited