isPeerDID function

bool isPeerDID(
  1. String peerDID
)

Validates if a given string matches the peer DID pattern.

peerDID - The string to validate.

Returns true if the string matches the peer DID pattern, false otherwise.

Implementation

bool isPeerDID(String peerDID) {
  return peerDIDPattern.hasMatch(peerDID);
}