UniversalVerifier class final
Allows verification of any supported Verifiable Credential (VC) encodings.
Combines a default set of verifiers (like expiry and integrity checks) and optional custom verifiers.
Supports custom document loaders for loading external resources during verification. This is useful for implementing custom caching strategies or for loading resources from non-standard locations.
Constructors
-
UniversalVerifier({List<
VcVerifier> ? customVerifiers, DocumentLoader? customDocumentLoader, DidResolver? didResolver}) -
Creates a UniversalVerifier.
factory
Properties
- customDocumentLoader → DocumentLoader?
-
Custom document loader for loading external resources during verification.
final
-
customVerifiers
→ List<
VcVerifier> -
List of custom verifiers provided during construction.
final
-
defaultVerifiers
→ List<
VcVerifier> -
Default verifiers always run during verification.
final
- didResolver → DidResolver?
-
Custom DID resolver for resolving DID documents during verification.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
ParsedVerifiableCredential data) → Future< VerificationResult> -
Verifies the provided
datausing both default and custom verifiers.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createWithCachedVerifiers(
{List< VcVerifier> ? customVerifiers, DocumentLoader? customDocumentLoader, DidResolver? didResolver}) → UniversalVerifier - Creates a UniversalVerifier with cached verifier instances.