Interface for parsers that decode serialized verifiable data.
Implementations of this interface provide methods to check if data can be decoded and to perform the actual decoding of verifiable credentials or presentations from their serialized formats.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canDecode(
SerializedType input) → bool -
Determines whether the
inputcan be decoded by this parser. -
decode(
SerializedType input) → DecodedType -
Decodes the
inputinto the appropriate data type. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited